@@ -16,6 +16,16 @@ animation
     gif_from_images
 
 
+async
+=====
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    await_callback
+
+
 colors
 ======
 
@@ -95,6 +105,7 @@ maps
     :nosignatures:
 
     geometric_key
+    reverse_geometric_key
     geometric_key2
     normalize_values
 
@@ -141,21 +152,22 @@ xfunc
 
 """
 from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
 
 
 def valuedict(keys, value, default):
     value = value or default
-
     if isinstance(value, dict):
         valuedict = {key: default for key in keys}
         valuedict.update(value)
     else:
         valuedict = {key: value for key in keys}
-
     return valuedict
 
 
 from .animation import *
+from .async_ import *
 from .coercing import *
 from .colors import *
 from .datetime_ import *
@@ -172,27 +184,4 @@ from .xfunc import *
 from .xscript import *
 from .functions import *
 
-from . import animation
-from . import coercing
-from . import colors
-from . import datetime_
-from . import decorators
-from . import encoders
-from . import itertools_
-from . import maps
-from . import mixing
-from . import names
-from . import profiling
-from . import remote
-from . import sorting
-from . import xfunc
-from . import xscript
-from . import functions
-
-__all__  = []
-__all__ += animation.__all__ + coercing.__all__ + colors.__all__
-__all__ += datetime_.__all__ + decorators.__all__ + encoders.__all__
-__all__ += itertools_.__all__ + maps.__all__ + mixing.__all__ + names.__all__
-__all__ += profiling.__all__ + remote.__all__ + sorting.__all__
-__all__ += xfunc.__all__ + xscript.__all__
-__all__ += functions.__all__
+__all__ = [name for name in dir() if not name.startswith('_')]
