@@ -28,7 +28,7 @@ from .utilities import *
 from . import utilities
 
 
-__version__ = '0.4.6'
+__version__ = '0.4.7'
 
 
 PURGE_ON_DELETE = True
@@ -49,10 +49,27 @@ def _get_ironpython_lib_path(version):
     ironpython_lib_path = os.path.join(ironpython_settings_path, 'lib')
 
     if not os.path.exists(ironpython_lib_path):
-        raise Exception("The lib folder for IronPython does not exist in this location: {}".format(
-            ironpython_lib_path))
+        raise Exception("The lib folder for IronPython does not exist in this location: {}".format(ironpython_lib_path))
 
     return ironpython_lib_path
 
 
+def _get_python_plugins_path(version):
+    if version not in ('5.0', '6.0'):
+        version = '5.0'
+
+    appdata = os.getenv('APPDATA')
+    python_plugins_path = os.path.join(appdata,
+                                       'McNeel',
+                                       'Rhinoceros',
+                                       '{}'.format(version),
+                                       'Plug-ins',
+                                       'PythonPlugins')
+
+    if not os.path.exists(python_plugins_path):
+        raise Exception("The PythonPlugins folder does not exist in this location: {}".format(python_plugins_path))
+
+    return python_plugins_path
+
+
 __all__ = [name for name in dir() if not name.startswith('_')]
